@@ -1,10 +1,10 @@
 # UMLS::Interface 
-# (Last Updated $Id: Interface.pm,v 1.143 2014/06/27 13:23:47 btmcinnes Exp $)
+# (Last Updated $Id: Interface.pm,v 1.145 2015/06/23 15:48:47 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
 #
-# Copyright (c) 2004-2011,
+# Copyright (c) 2004-2015,
 #
 # Bridget T. McInnes, University of Minnesota Twin Cities
 # bthomson at cs.umn.edu
@@ -421,7 +421,7 @@ my $pkg = "UMLS::Interface";
 
 use vars qw($VERSION);
 
-$VERSION = '1.41';
+$VERSION = '1.43';
 
 my $debug = 0;
 
@@ -1829,6 +1829,38 @@ sub findClosenessCentrality {
     return $closeness;
 }
 
+=head3 findAncestors
+
+description:
+
+ function that returns all the ancestors of a concept 
+
+input:   
+
+ $concept  <- the concept
+
+output:
+
+ %hash <- reference to hash containing ancestors
+
+example:
+
+ use UMLS::Interface;
+ my $umls = UMLS::Interface->new(); 
+ my $concept = "C0018563";
+ my $hash =  $umls->findAncestors($concept); 
+
+=cut
+sub findAncestors {
+
+    my $self = shift;
+    my $concept = shift;
+    
+    my $hash = $pathfinder->_findAncestors($concept);
+    
+    return $hash;
+}
+
 =head3 findShortestPathLength
 
 description:
