@@ -1,5 +1,5 @@
 # UMLS::Interface::PathFinder
-# (Last Updated $Id: PathFinder.pm,v 1.65 2014/06/27 13:23:47 btmcinnes Exp $)
+# (Last Updated $Id: PathFinder.pm,v 1.66 2015/06/23 14:17:23 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -2052,6 +2052,36 @@ sub _findMaximumDepthInRealTime {
     return $maximum_path_length;
 }
 
+#  method that finds all the ancestors of a given concept
+#  input : $concept1  <- the concept
+#  output: %ancestors <- hash containing the ancestors
+sub _findAncestors { 
+    my $self = shift;
+    my $concept = shift; 
+    
+    my $function = "_findAncestors";
+    &_debug($function);
+      
+    #  check self
+    if(!defined $self || !ref $self) {
+	$errorhandler->_error($pkg, $function, "", 2);
+    }
+
+    my @paths = $self->_pathsToRoot($concept);
+    
+    my %ancestors = (); 
+    foreach my $path (@paths) { 
+	foreach my $string (@{$path}) { 
+	    my @cuis = split/\s+/, $string; 
+	    foreach my $cui (@cuis) { 
+		$ancestors{$cui} = 1; 
+	    }
+	}
+    }
+    
+    return \%ancestors; 
+
+}
 #  method that finds the closeness centrality of a concept 
 #  input : $concept1  <- the concept
 #  output: $double    <- the closeness
@@ -2103,19 +2133,18 @@ sub _findShortestPathLength {
     }
 
     if($option_realtime) {
-	
-	my $length = $self->_findShortestPathLengthInCache($concept1, $concept2);
-	if(defined $length) { return $length; }
-	else { 
-	    my $length = $self->_findShortestPathLengthInRealTime($concept1, $concept2);
-	    if(!$option_undirected) { 
-		$self->_storeShortestPathLengthInCache($concept1, $concept2, $length);
-	    }
-	    return $length;
-	}
+
+	#my $length = $self->_findShortestPathLengthInCache($concept1, $concept2);
+	#if(defined $length) { return $length; }
+	#else { 
+	my $length = $self->_findShortestPathLengthInRealTime($concept1, $concept2);
+	    #if(!$option_undirected) { 
+		#$self->_storeShortestPathLengthInCache($concept1, $concept2, $length);
+	    #}
+	return $length;
+        #}
     }
     else {
-	
 	my $paths = $self->_findShortestPathThroughLCS($concept1, $concept2);
 	my $path = shift @{$paths};
 	if(defined $path) { 
